@@ -5,27 +5,32 @@ macro_rules! error {
             $($current_error_ident: ident),+
         }
     ) => {
+        use std::error::Error as DefineErrorError;
+        use std::fmt::Display as DefineErrorDisplay;
+        use std::fmt::Formatter as DefineErrorFormatter;
+        use std::fmt::Result as DefineErrorFmtResult;
+
         #[derive(Debug)]
         pub enum $main_error_ident {
             $($current_error_ident($current_error_ident)),+
         }
 
-        impl Display for $main_error_ident {
-            fn fmt(&self, f: &mut Formatter) -> fmt::Result {
+        impl DefineErrorDisplay for $main_error_ident {
+            fn fmt(&self, f: &mut DefineErrorFormatter) -> DefineErrorFmtResult {
                 match *self {
                     $($main_error_ident::$current_error_ident(ref err) => write!(f, "{}", err)),+
                 }
             }
         }
 
-        impl Error for $main_error_ident {
+        impl DefineErrorError for $main_error_ident {
             fn description(&self) -> &str {
                 match *self {
                     $($main_error_ident::$current_error_ident(ref err) => err.description()),+
                 }
             }
 
-            fn cause(&self) -> Option<&Error> {
+            fn cause(&self) -> Option<&DefineErrorError> {
                 match *self {
                     $($main_error_ident::$current_error_ident(ref err) => Some(err)),+
                 }
